@@ -2,10 +2,10 @@ from pathlib import Path
 
 from setuptools import setup
 
-from setuptools_cpp_cuda import CudaExtension, BuildExtension, fix_dll
+from setuptools_cpp_cuda import CUDAExtension, BuildExtension, fix_dll
 
 cuda_ext_path = Path('src/my_cuda_package/cuda_ext')
-cuda_ext = CudaExtension(
+cuda_ext = CUDAExtension(
     name='my_cuda_package.cuda_ext',
     include_dirs=[cuda_ext_path / 'include'],
     sources=[
